#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import flask
import io
from configuration import *
from gestion_erreurs import *
from gestion_donnees import *
from gestion_unites import *
from trace_courbe import *
from faq import *

import matplotlib.pyplot as plt

import base64

from matplotlib.backends.backend_agg import FigureCanvasAgg as FigureCanvas

app = flask.Flask(__name__)

@app.route('/',methods=['POST','GET'])
def index():
    liste_err = initialise_erreurs()    
    val_form = config_init()
    if flask.request.method=="POST":
        if 'fichier_donnees' in flask.request.files:
            ## charger les donneés dans le formulaire
            fichier = flask.request.files['fichier_donnees']
        
            val_form = fichier_json_vers_configdonnees(fichier,liste_err)
            #return str(val_form['nb_data'])
    return flask.render_template("index.html",err=liste_err[1],valform=val_form)

@app.route('/apropos')
def apropos():
    
    return flask.render_template("apropos.html",err=[])
 

@app.route("/courbe/<ext>", methods=['POST'])
def courbe_image(ext):
    liste_err = initialise_erreurs()
    data = flask.request.form
    
    # Régler la configuration et les données    
    config = gere_configuration(data,liste_err)    
    l_jours,l_poids = gere_donneespoids(data,config["naissance"],liste_err)
    
    #print(config)

    texte = donnees_vers_json(l_jours,l_poids,config)
    
    # noter le nom de l'enfant pour l'export
    nomenfant = simplifie_nom(config['nom'])

    # créer la figure
    try:
        fig = cree_figure(config,l_jours,l_poids,liste_err)
        result = "success"
        output = io.BytesIO()
        #warning("Là ça va",liste_err)
        FigureCanvas(fig).print_png(output)
        plt.close(fig)
    except:
        result = "fail"
        liste_err[0].append("Impossible de générer la courbe !")
    
    
    if ext == "b64":
        if result == "success":
            reponse = flask.jsonify({ "result":result, 
                "messages": liste_err[1], 
                "image": base64.b64encode(output.getvalue()).decode("ascii"),
                "export_txt": texte,
                "nomenfant": nomenfant})
        else:
            reponse = flask.jsonify({ "result":result, 
                "messages": liste_err[1]+liste_err[0], 
                "image": "",
                "export_txt": texte,
                "nomenfant": nomenfant})
        return reponse
        #return flask.Response(base64.b64encode(output.getvalue()), mimetype='text/plain')
    elif ext == "png" and result == "success":
        return flask.Response(output.getvalue(), mimetype='image/png')
    elif ext == "png":
        return flask.render_template("erreur_fatale.html",erreur="Impossible de générer la courbe")
    else:
        return flask.render_template("erreur_fatale.html",erreur="Le type d'image demandé n'est pas reconnu")
    
    #return flask.Response(base64.b64encode(output.getvalue()), mimetype='text/plain')

#@app.route("/export_donnees",methods=['POST'])
#def export_donnees():
#    # exporte les données au format texte
#    liste_err = initialise_erreurs()
#    data = flask.request.form
#    
#    config = gere_configuration(data,liste_err)
#    l_jours,l_poids = gere_donneespoids(data,config["naissance"],liste_err)
#
#    texte = configuration_vers_texte(config)
#    texte += donnees_poids_vers_texte(l_jours,l_poids)    
#    
#    #texte = donnees_vers_json(l_jours,l_poids,config)
#    #return flask.Response(texte,mimetype="application/json")
#    return flask.Response(texte,mimetype="text/plain")

@app.route("/faq")
def faq():
    
    table_faq = lire_fichier_csv_simple(fichier_FAQ)
    l_categ,table_qr = extraire_tables_par_cat(table_faq)

    return flask.render_template("faq.html",lcateg=l_categ,tableqr=table_qr,err=[])

@app.route("/changelog")
def changelog():
    
    table_version = lire_fichier_csv_simple(fichier_changelog)
    
    return flask.render_template("changelog.html",table = table_version,err=[])


if __name__ == "__main__":
    app.run(host='0.0.0.0',debug=True)